phenoCxR: Phenotypic Cascades x RAC875-2 zinc experiment data frame
Description
Zinc concentration data of a Doubled Haploid wheat population.
Usage
data(phenoCxR)
Arguments
Format
This data relates to a glasshouse experiment involving a set of 90
Doubled Haploid (DH) lines from a crossing of Cascades x Rac875-2. The
DH lines were allocated randomly to pots in the glasshouse using a
randomised complete block design. There were also additional pots
that contained 5 of each of the parents (Cascades and Rac-875-2). Two
measurments were made, namely zinc concentration and shoot length.
The data frame consists of 200 rows and 5 columns decribed below
id:
A factor of 92 levels conataining the unique
identification of the DH lines and parents.
Block:
A factor of two levels indexing the blocks in the experiment
Type:
A factor of 3 levels indexing the wheat variety (Doubled
Haploid, Cascades, Rac875-2)
shoot:
A numerical variable of shoot lengths for each plant
znconc:
A numerical variable of zinc concentration levels for each plant