Learn R Programming

wgaim (version 2.0-1)

tr.wgaim: Display diagnostic information about the QTL detected.

Description

Displays diagnostic infomation about QTL detection and significance for the sequence of models generated in a wgaim analysis.

Usage

# S3 method for wgaim
tr(object, iter = 1:length(object$QTL$effects),
      lik.out = TRUE, ...)

Value

For the selected QTL, a probability value matrix is displayed with rows specified by iter. If lik.out = TRUE then a matrix with rows consisting of the likelihood with additive genetic variance, the likelihood without additive genetic variance (NULL model), the test statistic and the p-value for the statistic.

Arguments

object

an object of class "wgaim"

iter

a vector of integers specifying what rows of the p-value matrix to display

lik.out

logical value. If TRUE then diagnostic information about the testing of the genetic variance is given for all iterations.

...

arguments passed to print.default for displaying of information

Author

Julian Taylor

Details

By default the printing of the objects occur with arguments quote = FALSE and right = TRUE. Users should avoid using these arguments.

References

Verbyla, A. P & Taylor, J. D, Verbyla, K. L (2012). RWGAIM: An efficient high dimensional random whole genome average (QTL) interval mapping approach. Genetics Research. 94, 291-306.

Julian Taylor, Arunas Vebyla (2011). R Package wgaim: QTL Analysis in Bi-Parental Populations Using Linear Mixed Models. Journal of Statistical Software, 40(7), 1-18. URL http://www.jstatsoft.org/v40/i07/.

See Also

wgaim

Examples

Run this code

if (FALSE) {
# read in data

data(phenoRxK, package = "wgaim")
data(genoRxK, package = "wgaim")

# subset linkage map and convert to "interval" object

genoRxK <- subset(genoRxK, chr = c("1A", "2D1", "2D2", "3B"))
genoRxK <- cross2int(genoRxK, impute = "Martinez", id = "Genotype")

# base model

rkyld.asf <- asreml(yld ~ lrow, random = ~ Genotype + Range,
                   residual = ~ ar1(Range):ar1(Row), data = phenoRxK)

# find QTL

rkyld.qtl <- wgaim(rkyld.asf, intervalObj = genoRxK, merge.by = "Genotype",
                   trace = "trace.txt", na.action = na.method(x = "include"))

# diagnostic check

tr(rkyld.qtl, digits = 4)
}

Run the code above in your browser using DataLab